/**
 * Copyright (c) 2011-2012 EBMWebsourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.commons.log;

import java.io.Serializable;

import javax.jbi.messaging.MessageExchange;

/**
 * 
 * This is an helper class to manipulate Flow attributes extracted from a {@link MessageExchange}.
 * 
 * This is not meant to be stored as-is in the properties of the {@link MessageExchange} because of possible
 * classloading issues (use {@link FlowAttributesExchangeHelper} instead).
 * 
 * @author Marc Jambert - EBM WebSourcing
 */
public final class FlowAttributes implements Serializable {

    private static final long serialVersionUID = 4738056957627586922L;

    private final String flowInstanceId;

    private final String flowStepId;

    public FlowAttributes(final String flowInstanceId, final String flowStepId) {
        assert flowInstanceId != null;
        assert flowStepId != null;
        this.flowInstanceId = flowInstanceId;
        this.flowStepId = flowStepId;
    }

    public String getFlowInstanceId() {
        return flowInstanceId;
    }

    public String getFlowStepId() {
        return flowStepId;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((flowInstanceId == null) ? 0 : flowInstanceId.hashCode());
        result = prime * result + ((flowStepId == null) ? 0 : flowStepId.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        FlowAttributes other = (FlowAttributes) obj;
        if (flowInstanceId == null) {
            if (other.flowInstanceId != null)
                return false;
        } else if (!flowInstanceId.equals(other.flowInstanceId))
            return false;
        if (flowStepId == null) {
            if (other.flowStepId != null)
                return false;
        } else if (!flowStepId.equals(other.flowStepId))
            return false;
        return true;
    }

    @Override
    public String toString() {
        return "Flow[instance=" + flowInstanceId + ", step=" + flowStepId + "]";
    }

    

}
